==> banshee-1-0.98.1.tar.gz: banshee-1-0.98.1/src/Core/Banshee.Core/Banshee.IO/Utilities.cs <==
/***************************************************************************
 *  Utilities.cs
 *
 *  Copyright (C) 2006 Novell, Inc.
 *  Written by Aaron Bockover <aaron@abock.org>
 ****************************************************************************/

/*  THIS FILE IS LICENSED UNDER THE MIT LICENSE AS OUTLINED IMMEDIATELY BELOW: 
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a
 *  copy of this software and associated documentation files (the "Software"),  
 *  to deal in the Software without restriction, including without limitation  
 *  the rights to use, copy, modify, merge, publish, distribute, sublicense,  
 *  and/or sell copies of the Software, and to permit persons to whom the  
 *  Software is furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in 
 *  all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 *  DEALINGS IN THE SOFTWARE.
 */

using System;

using Banshee.Base;

namespace Banshee.IO
{
    public static class Utilities
    {
        public static void DeleteFileTrimmingParentDirectories(SafeUri uri)
        {
            /*Banshee.IO.IOProxy.File.Delete(uri);
            
            try {
                string old_dir = System.IO.Path.GetDirectoryName(uri.LocalPath);
                while(old_dir != null && old_dir != String.Empty) {
                    Banshee.IO.IOProxy.Directory.Delete(old_dir);
                    old_dir = System.IO.Path.GetDirectoryName(old_dir);
                }
            } catch {
            }*/
        }
    }
}

==> banshee-1-1.5.6.tar.gz: banshee-1-1.5.6/src/Core/Banshee.Core/Banshee.IO/Utilities.cs <==
/***************************************************************************
 *  Utilities.cs
 *
 *  Copyright (C) 2006 Novell, Inc.
 *  Written by Aaron Bockover <aaron@abock.org>
 ****************************************************************************/

/*  THIS FILE IS LICENSED UNDER THE MIT LICENSE AS OUTLINED IMMEDIATELY BELOW:
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a
 *  copy of this software and associated documentation files (the "Software"),
 *  to deal in the Software without restriction, including without limitation
 *  the rights to use, copy, modify, merge, publish, distribute, sublicense,
 *  and/or sell copies of the Software, and to permit persons to whom the
 *  Software is furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in
 *  all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 *  DEALINGS IN THE SOFTWARE.
 */

using System;

using Banshee.Base;

namespace Banshee.IO
{
    public static class Utilities
    {
        public static void DeleteFileTrimmingParentDirectories (SafeUri uri)
        {
            Banshee.IO.File.Delete (uri);
            TrimEmptyDirectories (uri);
        }

        public static void TrimEmptyDirectories (SafeUri uri)
        {
            try {
                string old_dir = System.IO.Path.GetDirectoryName (uri.LocalPath);
                while (old_dir != null && old_dir != String.Empty) {
                    Banshee.IO.Directory.Delete (old_dir);
                    old_dir = System.IO.Path.GetDirectoryName (old_dir);
                }
            } catch {
            }
        }
    }
}
